# LOLComicGrabber

LOLComicGrabber is a python package aimed at making downloading the League of Legends comic books possible. I made this because I didn't want to be limited to a browser and internet connection to read one of these comics. LOLComicGrabber aims to make the League of Legends comics accessible.

